@@ -7,7 +7,7 @@ from ssht00ls.classes import utils
 from ssht00ls.classes import agent, keys, aliases, ssh, smartcards, ssync, smb
 
 # the client object class.
-class Client(syst3m.objects.Traceback):
+class Client(Traceback):
 	def __init__(self,
 		# the alias (required) (param #1).
 		alias=None,
@@ -34,7 +34,7 @@ class Client(syst3m.objects.Traceback):
 	):
 
 		# defaults.
-		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.Client", raw_traceback="ssht00ls.classes.client.Client")
+		Traceback.__init__(self, traceback="ssht00ls.Client", raw_traceback="ssht00ls.classes.client.Client")
 
 		# parameters by dict.
 		if parameters != {}:
@@ -94,6 +94,10 @@ class Client(syst3m.objects.Traceback):
 		self.smb = smb.SMB(
 			alias=alias,)
 
+		# shortcuts.
+		self.pull = self.ssync.pull
+		self.push = self.ssync.push
+
 		# vars.
 		try: 	self.public_key_data = Files.load(public_key)
 		except: self.public_key_data = None
@@ -120,7 +124,7 @@ class Client(syst3m.objects.Traceback):
 		if not response.success: return response
 
 		# handler.
-		return r3sponse.success(f"Successfully generated client {self.alias_}.")
+		return Response.success(f"Successfully generated client {self.alias_}.")
 
 		#
 	def create(self, 
@@ -142,7 +146,7 @@ class Client(syst3m.objects.Traceback):
 		if not response.success: return response		
 
 		# handler.
-		return r3sponse.success(f"Successfully generated client {self.alias_}.")
+		return Response.success(f"Successfully generated client {self.alias_}.")
 
 		#
 	def check(self):
@@ -175,14 +179,14 @@ class Client(syst3m.objects.Traceback):
 					if info["pin"] in [False, None, "", "none", "None"]:
 						no_passphrase = True
 					else:
-						response = encryption.encryption.decrypt(info["pin"])
+						response = ssht00ls_agent.encryption.decrypt(info["pin"])
 						if not response.success: return response
 						pin = response.decrypted.decode()
 				else:
 					if info["passphrase"] in [False, None, "", "none", "None"]:
 						no_passphrase = True
 					else:
-						response = encryption.encryption.decrypt(info["passphrase"])
+						response = ssht00ls_agent.encryption.decrypt(info["passphrase"])
 						if not response.success: return response
 						passphrase = response.decrypted.decode()
 
@@ -201,7 +205,7 @@ class Client(syst3m.objects.Traceback):
 		if not response.success: return response
 
 		# handler.
-		return r3sponse.success(f"Successfully checked client [{self.alias_}].")
+		return Response.success(f"Successfully checked client [{self.alias_}].")
 
 		#
 	def connect(self):
@@ -274,22 +278,39 @@ class Client(syst3m.objects.Traceback):
 		return self.alias.serial_numbers
 
 # the initialized clients.
-class Clients(syst3m.objects.Traceback):
-	def __init__(self):
+class Clients(Traceback):
+	def __init__(self,
+		# select a preset of clients (append "*" to preset to use all).
+		preset=["*"],
+	):
 
 		# defaults.
-		syst3m.objects.Traceback.__init__(self, traceback="ssht00ls.clients", raw_traceback="ssht00ls.classes.client.Clients")
+		Traceback.__init__(self, traceback="ssht00ls.clients", raw_traceback="ssht00ls.classes.client.Clients")
 
 		# attributes.
+		self.preset = preset
 		self.__clients__ = {}
 
 		#
 	
 	# initialize.
-	def initialize(self):
-		for alias, info in aliases.aliases.iterate():
-			self[alias] = Client(parameters=info)
-	
+	def initialize(self, preset=None):
+		if preset == None: preset = self.preset
+		if preset in ["*","all"] or "*" in preset or  "all" in preset: 
+			items = aliases.aliases.iterate()
+		else:
+			items = []
+			for alias in preset:
+				response = aliases.info(alias=alias)
+				if not response.success: return response
+				items.append([alias, response.info])
+		self.__clients__ = {}
+		for alias, info in items:
+			self.__clients__[alias] = Client(parameters=info)
+		return Response.success(f"Successfully initialized {len(self.__clients__)} client(s).")
+
+		#
+
 	# iterate.
 	def __iter__(self):
 		return iter(self.__clients__)
@@ -302,7 +323,9 @@ class Clients(syst3m.objects.Traceback):
 		for i in clients:
 			items.append([i, self.__clients__[i]])
 		return items
-	
+		
+		#
+
 	# get & set client.
 	def __setitem__(self, key, value):
 		if isinstance(key, (int, Integer)):
@@ -312,7 +335,9 @@ class Clients(syst3m.objects.Traceback):
 		if isinstance(key, (int, Integer)):
 			key = list(self.__clients__.keys())[key]
 		return self.__clients__[key]
-	
+		
+		#
+
 	# support [>=, <=, <, >] operators.
 	def __gt__(self, clients):
 		if isinstance(clients, int):
@@ -347,6 +372,8 @@ class Clients(syst3m.objects.Traceback):
 			raise exceptions.FormatError(f"Can not compare object {self.__class__} & {clients.__class__}.")
 		return len(self.__clients__) <= clients
 
+		#
+
 	# support [==, !=] operators.
 	def __eq__(self, clients):
 		if isinstance(clients, self.__class__):
@@ -361,6 +388,8 @@ class Clients(syst3m.objects.Traceback):
 			return True
 		return Dictionary(self.__clients__) != Dictionary(clients)
 
+		#
+
 	# support +.
 	def __concat__(self, clients):
 		if isinstance(clients, self.__class__):
@@ -369,17 +398,21 @@ class Clients(syst3m.objects.Traceback):
 			raise exceptions.FormatError(f"Can not concat object {self.__class__} & {clients.__class__}.")
 		return Dictionary(self.__clients__) + Dictionary(clients)
 
+		#
+
 	# support 'in' operator.
-	def __contains__(self, client):
-		if isinstance(client, (list, Files.Array)):
-			for i in client:
+	def __contains__(self, alias):
+		# always convert alias fo str client for aliases etc.
+		if isinstance(alias, (list, Files.Array)):
+			for i in alias:
 				if str(i) in list(self.__clients__.keys()):
 					return True
 			return False
 		else:
-			return str(client) in list(self.__clients__.keys())
+			return str(alias) in list(self.__clients__.keys())
+		
 		#
-	
+		
 	# representations.
 	def __repr__(self):
 		return str(self)
@@ -394,6 +427,7 @@ class Clients(syst3m.objects.Traceback):
 	def __len__(self):
 		return len(self.__clients__)
 
+		#
 	#
 
 # initialized objects.
