@@ -17,16 +17,8 @@ class SSHD(Traceback):
 
 		# check downloads.
 		if CHECKS:
-			utils_lib = gfp.clean(path=f"{SOURCE_PATH}/classes/utils/")
-			for subpath, url in [
-				["handler", "https://raw.githubusercontent.com/vandenberghinc/ssht00ls/master/ssht00ls/lib/utils/handler"],
-			]:
-				full_path = gfp.clean(f"{utils_lib}/{subpath}")
-				if not Files.exists(full_path):
-					os.system(f"rm -fr {full_path}")
-					os.system(f"curl -s {url} -o {full_path} && chmod +x {full_path}")
-					if not os.path.exists(full_path):
-						raise exceptions.ModuleError("Failed to install the ssht00ls utils (#1).")
+			response = self.__install_utils__(usernames=[Defaults.vars.user])
+			if not response.success: response.crash()
 
 	def create(self,
 		# save the configuration & banner.
@@ -259,14 +251,14 @@ class SSHD(Traceback):
 		for username in usernames:
 			
 			# non existant.
-			fp = FilePath(f"{Defaults.vars.homes}{username}/.ssht00ls/utils/.version.py")
+			fp = FilePath(f"{Defaults.vars.homes}{username}/.ssht00ls/utils/.version")
 			if not fp.exists(sudo=True): 
 				to_install.append(username)
 
 			# check version.
 			else: 
 				version = utils.__execute__(["sudo", "cat", fp.path])
-				github_version = utils.__execute__(["curl", "https://raw.githubusercontent.com/vandenberghinc/ssht00ls/master/.version.py?raw=true"])
+				github_version = utils.__execute__(["curl", "https://raw.githubusercontent.com/vandenberghinc/ssht00ls/master/.version?raw=true"])
 				if str(version) != str(github_version):
 					to_install.append(username)
 
@@ -288,17 +280,9 @@ class SSHD(Traceback):
 
 		# create tmp lib.
 		utils_lib = gfp.clean(path=f"{SOURCE_PATH}/lib/utils/")
-		utils_tmp = "/tmp/utils/"
-		if not os.path.exists(utils_lib):
-			raise ValueError(f"ssht00ls library [{utils_lib}] does not exist.")
-		Files.copy(utils_lib, utils_tmp)
-		Files.copy(f"{SOURCE_PATH}/.version.py", f"{utils_tmp}.version.py")
-		Files.delete(f"{utils_tmp}/__pycache__")
-		Files.delete(f"{utils_tmp}/__init__.py")
-		Files.chmod(f"{utils_tmp}/*", "+x")
-		if not Files.exists(utils_tmp):
-			return Response.error("Failed to install the ssht00ls utils (#2).")
-
+		Files.copy(f"{SOURCE_PATH}/.version", f"{utils_lib}.version")
+		Files.chmod(f"{utils_lib}/*", "+x")
+		
 		# iterate.
 		for username in usernames:
 
@@ -315,7 +299,7 @@ class SSHD(Traceback):
 			if not Files.exists(fp.base(), sudo=True):
 				Files.create(path=fp.base(), sudo=True, directory=True)
 			fp.delete(sudo=True, forced=True)
-			Files.copy(utils_tmp, fp.path, sudo=True)
+			Files.copy(utils_lib, fp.path, sudo=True)
 			fp.ownership.set(owner=username, group=None, sudo=True, recursive=True)
 			fp.permission.set(permission=755, recursive=True, sudo=True)
 			if not fp.exists(sudo=True):
