@@ -36,7 +36,7 @@ def size(path, alias=None, log_level=0):
 		})
 	else:
 		return execute(
-			command=f"""ssh {DEFAULT_SSH_OPTIONS} {alias} ' python3 /usr/local/lib/ssht00ls/classes/utils/size.py {path} --non-interactive ' '""",
+			command=f"""ssh {DEFAULT_SSH_OPTIONS} {alias} ' python3 /usr/local/lib/ssht00ls/lib/utils/size {path} --non-interactive ' '""",
 			message=f"Successfully retrieved the size of [{alias}:{path}].",
 			log_level=log_level,
 			serialize=True,)
